import sys
sys.path.append(".")

import voms

valid_cert = """-----BEGIN CERTIFICATE-----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-----END CERTIFICATE-----"""

valid_cert_chain = """-----BEGIN CERTIFICATE-----
MIIEaTCCA1GgAwIBAgICKAswDQYJKoZIhvcNAQELBQAwQzESMBAGCgmSJomT8ixk
ARkWAmVzMRgwFgYKCZImiZPyLGQBGRYIaXJpc2dyaWQxEzARBgNVBAMTCklSSVNH
cmlkQ0EwHhcNMTUwMzI1MTM1NjU0WhcNMTYwMzI0MTM1NjU0WjBUMRIwEAYKCZIm
iZPyLGQBGRYCZXMxGDAWBgoJkiaJk/IsZAEZFghpcmlzZ3JpZDENMAsGA1UEChME
aWZjYTEVMBMGA1UEAxMMYWx2YXJvLWxvcGV6MIIBIjANBgkqhkiG9w0BAQEFAAOC
AQ8AMIIBCgKCAQEAvdFq4YKKrc+3auxOIzUEZpd/wOkMMCVq6P4w1Q6kTYG4KOrS
O0vDNDJ/9+DCwGEu9umMvFLBlDzrsDm0ec7KVafcBFhM9WrJB81lbTgfxtIT6Nxx
JEqwoxLvMiZOiL3bIWRE2cTTFoO0KEHTCcVnLaV5OaO+2Iq8dP8Z3x6jlf/gQFE4
Yk9h4k+F3h/nHeN/NwoOJRKID88NgTImUtGjGNi9EmuBX/pQxVKMExE64mBWXQKa
D+5ZGjDevvqVyQOlVTBlJysvH2ujpiljL8Of24yVsX1CGFPwnoAmFF4uUQ2zbe35
w2iQMa91FUbEVk2lRLDCAJlEbuCIRKQHXlExIQIDAQABo4IBVDCCAVAwDAYDVR0T
AQH/BAIwADAdBgNVHQ4EFgQUcX8iKHfNYxzet3Vbq/RWIU1IUycwHwYDVR0jBBgw
FoAUnUJkLlupXvH/bMg8NtPxtkOYrRowDgYDVR0PAQH/BAQDAgSwMB0GA1UdJQQW
MBQGCCsGAQUFBwMCBggrBgEFBQcDBDBJBgNVHREEQjBAhihodHRwOi8vcGtpLmly
aXNncmlkLmVzL2F1ZGl0Lz9pZD1hMjViOGM5gRRhbG9nYUBpZmNhLnVuaWNhbi5l
czAiBgNVHRIEGzAZhhdodHRwOi8vcGtpLmlyaXNncmlkLmVzLzA4BgNVHR8EMTAv
MC2gK6AphidodHRwOi8vcGtpLmlyaXNncmlkLmVzL2NhL2NybC9jYWNybC5jcmww
KAYDVR0gBCEwHzAPBg0rBgEEAbp7AgIEAQUAMAwGCiqGSIb3TAUCAgEwDQYJKoZI
hvcNAQELBQADggEBADERDD95nDbgVf1MQyklwUL+cqAOaMGehSB8Mbf+rfVmnrH4
R4S8467UjQ8UcX8/irgyWatzt0IWqK9lKbvZwZ9GSOkDTe4vlYJPwZ6udOtjm8s2
ntgj3Hgzo33xgPjUJu2gPi5KZ+vm8Sxnr30zun6sUvC9+mTvCRL8SgRh8nXGL+xV
qHua8HYgiFfaGJryddYqRRfcyl2paTiDBKxACeYA4jk9gHGroGMtl5fg0b3oJvxY
Gkrhn8zGLNqRofgndfUvFdM4/QrKh1cH3fPiVVPywix/AzlK5ExD5sFyXqBmrsGZ
NHYhHo86fzmw56WjJAiX0XCgjwsHH0+qNDJvCMs=
-----END CERTIFICATE-----"""


v = voms.VOMS(valid_cert, valid_cert_chain)
print v

#with voms.VOMS("/etc/grid-security/vomsdir/",
#               "/etc/grid-security/certificates/",
#               "libvomsapi.so.1") as v:
#
#    v.load_cert(valid_cert)
#    v.load_chain([valid_cert_chain])
#    print dir(v)
#    v.retrieve()
#    print v.voname
